Struct diwata_intel::data_container::Filter [−][src]
a limited filter structure which is used for the simple usecase of the client all conditions are AND together, and the operator depends on the data type of the column name String will be ILIKE '%?' Date will be in between number will text_cast then ilike
Fields
conditions: Vec<Condition>
Methods
impl Filter[src]
impl Filter